webbpsf\_ext.spectra
====================

.. automodule:: webbpsf_ext.spectra

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
      :toctree:
   
      BOSZ_2024_spectrum
      BOSZ_filename
      BOSZ_filename_2024
      BOSZ_spectrum
      bin_spectrum
      companion_spec
      cond_filter
      cond_table
      download_BOSZ_2024
      download_BOSZ_spectrum
      download_votable
      jupiter_spec
      linder_filter
      linder_table
      mag_to_counts
      mass_sensitivity_table
      sp_accr
      stellar_spectrum
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :toctree:
      :template: custom-class-template.rst
   
      planets_sb12
      source_spectrum
   
   

   
   
   



